% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TESS.R
\name{tess_do_everything}
\alias{tess_do_everything}
\title{TESS function to do everything}
\usage{
tess_do_everything(
  gen,
  coords,
  grid = NULL,
  Kvals = 1:10,
  K_selection = "manual",
  plot_method = "maxQ",
  col_breaks = 20,
  minQ = 0.1,
  tess_method = "projected.ls",
  lambda = 1,
  ploidy = 2,
  correct_kriged_Q = TRUE,
  quiet = FALSE
)
}
\arguments{
\item{gen}{genotype dosage matrix (rows = individuals & columns = snps) or \code{vcfR} object}

\item{coords}{dataframe with x and y coordinates}

\item{grid}{SpatRaster for kriging}

\item{Kvals}{vector of K values to test}

\item{K_selection}{how to perform K selection ("manual" to enter into console (default) or "auto" for automatic selection based on \link[algatr]{bestK})}

\item{plot_method}{method for making rainbow map of kriged layers (options: "maxQ" to only plot the max Q value for each cell (default), "allQ" to plot all Q values greater than \code{minQ}, "maxQ_poly" or "allQ_poly" to create the plots as previously described, but as polygons for each K instead of continuous Q values)}

\item{col_breaks}{number of breaks for plotting (defaults to 20)}

\item{minQ}{threshold for minimum Q value for rainbow plotting if \code{method = "all"} is used (defaults to 0.10)}

\item{tess_method}{the type of TESS method to be run ("projected.ls" for projected least squares algorithm (default) or "qp" for quadratic programming algorithm)}

\item{lambda}{numeric value for the spatial regularization parameter. The default value lambda = 1 attributes equal weights to the loss function and to the penalty function.}

\item{ploidy}{ploidy of data (defaults to 2)}

\item{correct_kriged_Q}{whether to correct kriged Q values so values greater than 1 are set to 1 and values less than 0 are set to 0 (defaults to TRUE)}

\item{quiet}{whether to print output tables and figures (defaults to FALSE)}
}
\value{
list with all TESS results, final K value, and final kriged raster
}
\description{
TESS function to do everything
}
\details{
TESS is run using the tess3r package: Caye, K., François, O. (2016). tess3r: Inference of Spatial Population Genetic Structure. R package version 1.1.0.
See also: Caye, K., Deist, T.M., Martins, H., Michel, O., François, O. (2016). TESS3: fast inference of spatial population structure and genome scans for selection. Mol. Ecol. Res. 16(2):540-548. https://doi.org/10.1111/1755-0998.12471
}
\seealso{
Other TESS functions: 
\code{\link{allK_plot_helper}()},
\code{\link{bestK}()},
\code{\link{ggbarplot_helper}()},
\code{\link{krig_legend}()},
\code{\link{pops_helper}()},
\code{\link{tess_barplot}()},
\code{\link{tess_col_default}()},
\code{\link{tess_ggbarplot}()},
\code{\link{tess_ggplot}()},
\code{\link{tess_krig}()},
\code{\link{tess_ktest}()},
\code{\link{tess_plot_allK}()}
}
\concept{TESS functions}
